@@ -3,29 +3,34 @@ use std::str::FromStr;
 use tombi_uri::SchemaUri;
 
 use crate::value::{
-    EmptyFormatRules, TombiValueDirectiveContent, WithCommonLintRules, WithKeyTableLintRules,
+    EmptyFormatRules, TombiValueDirectiveContent, WithCommonFormatRules, WithCommonLintRules,
+    WithKeyFormatRules, WithKeyTableLintRules,
 };
 use crate::TombiCommentDirectiveImpl;
 
 pub type BooleanFormatRules = EmptyFormatRules;
 
-pub type KeyBooleanCommonLintRules = WithKeyTableLintRules<WithCommonLintRules<BooleanLintRules>>;
-
+pub type BooleanCommonFormatRules = WithCommonFormatRules<BooleanFormatRules>;
 pub type BooleanCommonLintRules = WithCommonLintRules<BooleanLintRules>;
 
-impl TombiCommentDirectiveImpl
-    for TombiValueDirectiveContent<BooleanFormatRules, KeyBooleanCommonLintRules>
-{
+pub type KeyBooleanCommonFormatRules = WithKeyFormatRules<BooleanCommonFormatRules>;
+pub type KeyBooleanCommonLintRules = WithKeyTableLintRules<BooleanCommonLintRules>;
+
+pub type TombiBooleanDirectiveContent =
+    TombiValueDirectiveContent<BooleanCommonFormatRules, BooleanCommonLintRules>;
+
+pub type TombiKeyBooleanDirectiveContent =
+    TombiValueDirectiveContent<KeyBooleanCommonFormatRules, KeyBooleanCommonLintRules>;
+
+impl TombiCommentDirectiveImpl for TombiBooleanDirectiveContent {
     fn comment_directive_schema_url() -> SchemaUri {
-        SchemaUri::from_str("tombi://json.tombi.dev/tombi-key-boolean-directive.json").unwrap()
+        SchemaUri::from_str("tombi://json.tombi.dev/tombi-boolean-directive.json").unwrap()
     }
 }
 
-impl TombiCommentDirectiveImpl
-    for TombiValueDirectiveContent<BooleanFormatRules, BooleanCommonLintRules>
-{
+impl TombiCommentDirectiveImpl for TombiKeyBooleanDirectiveContent {
     fn comment_directive_schema_url() -> SchemaUri {
-        SchemaUri::from_str("tombi://json.tombi.dev/tombi-boolean-directive.json").unwrap()
+        SchemaUri::from_str("tombi://json.tombi.dev/tombi-key-boolean-directive.json").unwrap()
     }
 }
 
