@@ -6,18 +6,27 @@ use crate::{printer::Simple, Diagnostic, Level, Print};
 pub struct Pretty;
 
 impl Print<Pretty> for Level {
-    fn print(&self, _printer: &mut Pretty) {
-        self.print(&mut Simple);
+    fn print(&self, _printer: &mut Pretty, use_ansi_color: bool) {
+        self.print(&mut Simple, use_ansi_color);
     }
 }
 
 impl Print<Pretty> for Diagnostic {
-    fn print(&self, printer: &mut Pretty) {
-        self.level().print(printer);
-        println!(": {}", Style::new().bold().paint(self.message()));
+    fn print(&self, printer: &mut Pretty, use_ansi_color: bool) {
+        self.level().print(printer, use_ansi_color);
+
+        let (message_style, at_style, link_style) = if use_ansi_color {
+            (
+                Style::new().bold(),
+                Style::new().fg(Color::DarkGray),
+                Style::new().fg(Color::Cyan),
+            )
+        } else {
+            (Style::new(), Style::new(), Style::new())
+        };
+
+        println!(": {}", message_style.paint(self.message()));
 
-        let at_style: Style = Style::new().fg(Color::DarkGray);
-        let link_style: Style = Style::new().fg(Color::Cyan);
         if let Some(source_file) = self.source_file() {
             println!(
                 "    {} {}",
