@@ -5,5 +5,5 @@ mod walk_dir;
 
 pub use error::Error;
 pub use file_match::{matches_file_patterns, MatchResult};
-pub use file_search::{FileInputType, FileSearch};
+pub use file_search::{search_pattern_matched_paths, FileInputType, FileSearch};
 pub use walk_dir::WalkDir;
