@@ -333,6 +333,26 @@ mod tests {
             ) -> Ok(_);
         }
 
+        test_lint! {
+            #[test]
+            fn test_tombi_schema_format_array_bracket_space_width_eq_0(
+                r#"
+                [format]
+                array-bracket-space-width = 0
+                "#,
+                tombi_schema_path(),
+            ) -> Err([
+                tombi_validator::DiagnosticKind::Deprecated(
+                    tombi_schema_store::SchemaAccessors::from(
+                        vec![
+                            tombi_schema_store::SchemaAccessor::Key("format".to_string()),
+                            tombi_schema_store::SchemaAccessor::Key("array-bracket-space-width".to_string()),
+                        ]
+                    ),
+                )
+            ]);
+        }
+
         test_lint! {
             #[test]
             fn test_tombi_schema_invalid_root(
@@ -344,11 +364,16 @@ mod tests {
                 "#,
                 tombi_schema_path(),
             ) -> Err([
-                tombi_validator::DiagnosticKind::DeprecatedValue(tombi_schema_store::SchemaAccessors::from(vec![
-                    tombi_schema_store::SchemaAccessor::Key("schemas".to_string()),
-                    tombi_schema_store::SchemaAccessor::Index,
-                    tombi_schema_store::SchemaAccessor::Key("root-keys".to_string()),
-                ]), "\"tool.taskipy\"".to_string()),
+                tombi_validator::DiagnosticKind::DeprecatedValue(
+                    tombi_schema_store::SchemaAccessors::from(
+                        vec![
+                            tombi_schema_store::SchemaAccessor::Key("schemas".to_string()),
+                            tombi_schema_store::SchemaAccessor::Index,
+                            tombi_schema_store::SchemaAccessor::Key("root-keys".to_string()),
+                        ]
+                    ),
+                    "\"tool.taskipy\"".to_string(),
+                )
             ]);
         }
 
@@ -687,11 +712,12 @@ mod tests {
                 "#,
             ) -> Err([
                 tombi_validator::DiagnosticKind::DeprecatedValue(
-                    tombi_schema_store::SchemaAccessors::from(vec![
+                    tombi_schema_store::SchemaAccessors::from(
+                        vec![
                         tombi_schema_store::SchemaAccessor::Key("lint".to_string()),
                         tombi_schema_store::SchemaAccessor::Key("disable".to_string()),
                     ]),
-                    "true".to_string()
+                    "true".to_string(),
                 )
             ]);
         }
