@@ -3,7 +3,7 @@ use std::borrow::Cow;
 use tombi_future::Boxable;
 use tombi_schema_store::{Accessor, CurrentSchema, SchemaContext, SchemaUri};
 
-use crate::hover::display_value::GetEnumerate;
+use crate::{hover::display_value::GetEnumerate, HoverContent};
 
 use super::{
     constraints::ValueConstraints, display_value::DisplayValue, GetHoverContent, HoverValueContent,
@@ -18,10 +18,16 @@ pub fn get_all_of_hover_content<'a: 'b, 'b, T>(
     schema_uri: &'a SchemaUri,
     definitions: &'a tombi_schema_store::SchemaDefinitions,
     schema_context: &'a SchemaContext,
-) -> tombi_future::BoxFuture<'b, Option<HoverValueContent>>
+) -> tombi_future::BoxFuture<'b, Option<HoverContent>>
 where
-    T: GetHoverContent + Sync + Send,
+    T: GetHoverContent + Sync + Send + std::fmt::Debug,
 {
+    tracing::trace!("value = {:?}", value);
+    tracing::trace!("keys = {:?}", keys);
+    tracing::trace!("accessors = {:?}", accessors);
+    tracing::trace!("all_of_schema = {:?}", all_of_schema);
+    tracing::trace!("schema_uri = {:?}", schema_uri);
+
     async move {
         let mut title_description_set = ahash::AHashSet::new();
         let mut value_type_set = indexmap::IndexSet::new();
@@ -63,16 +69,28 @@ where
                 )
                 .await
             {
-                if hover_content.title.is_some() || hover_content.description.is_some() {
-                    title_description_set.insert((
-                        hover_content.title.clone(),
-                        hover_content.description.clone(),
-                    ));
-                }
-                value_type_set.insert(hover_content.value_type);
+                match hover_content {
+                    HoverContent::Value(hover_value_content) => {
+                        if hover_value_content.title.is_some()
+                            || hover_value_content.description.is_some()
+                        {
+                            title_description_set.insert((
+                                hover_value_content.title.clone(),
+                                hover_value_content.description.clone(),
+                            ));
+                        }
+                        value_type_set.insert(hover_value_content.value_type);
 
-                if let Some(c) = hover_content.constraints {
-                    constraints = Some(c);
+                        if let Some(c) = hover_value_content.constraints {
+                            constraints = Some(c);
+                        }
+                    }
+                    HoverContent::Directive(hover_content) => {
+                        return Some(HoverContent::Directive(hover_content))
+                    }
+                    HoverContent::DirectiveContent(hover_content) => {
+                        return Some(HoverContent::DirectiveContent(hover_content))
+                    }
                 }
             }
         }
@@ -122,15 +140,15 @@ where
             }
         }
 
-        Some(HoverValueContent {
+        Some(HoverContent::Value(HoverValueContent {
             title,
             description,
-            accessors: tombi_schema_store::Accessors::new(accessors.to_vec()),
+            accessors: tombi_schema_store::Accessors::from(accessors.to_vec()),
             value_type,
             constraints,
             schema_uri: Some(schema_uri.to_owned()),
             range: None,
-        })
+        }))
     }
     .boxed()
 }
@@ -143,7 +161,7 @@ impl GetHoverContent for tombi_schema_store::AllOfSchema {
         accessors: &'a [Accessor],
         current_schema: Option<&'a CurrentSchema<'a>>,
         schema_context: &'a SchemaContext,
-    ) -> tombi_future::BoxFuture<'b, Option<HoverValueContent>> {
+    ) -> tombi_future::BoxFuture<'b, Option<HoverContent>> {
         async move {
             let Some(current_schema) = current_schema else {
                 unreachable!("schema must be provided");
@@ -151,10 +169,19 @@ impl GetHoverContent for tombi_schema_store::AllOfSchema {
 
             let mut title_description_set = ahash::AHashSet::new();
             let mut value_type_set = indexmap::IndexSet::new();
-            let mut schemas = self.schemas.write().await;
+            let mut enumerate_values = Vec::new();
+            let default = self
+                .default
+                .as_ref()
+                .and_then(|default| DisplayValue::try_from(default).ok());
 
-            for referable_schema in schemas.iter_mut() {
-                let Ok(Some(CurrentSchema { value_schema, .. })) = referable_schema
+            for referable_schema in self.schemas.write().await.iter_mut() {
+                let Ok(Some(CurrentSchema {
+                    value_schema,
+                    schema_uri,
+                    definitions,
+                    ..
+                })) = referable_schema
                     .resolve(
                         current_schema.schema_uri.clone(),
                         current_schema.definitions.clone(),
@@ -162,7 +189,7 @@ impl GetHoverContent for tombi_schema_store::AllOfSchema {
                     )
                     .await
                 else {
-                    return None;
+                    continue;
                 };
                 if value_schema.title().is_some() || value_schema.description().is_some() {
                     title_description_set.insert((
@@ -171,6 +198,14 @@ impl GetHoverContent for tombi_schema_store::AllOfSchema {
                     ));
                 }
                 value_type_set.insert(value_schema.value_type().await);
+
+                if let Some(values) = value_schema
+                    .as_ref()
+                    .get_enumerate(&schema_uri, &definitions, schema_context)
+                    .await
+                {
+                    enumerate_values.extend(values);
+                }
             }
 
             let (mut title, mut description) = if title_description_set.len() == 1 {
@@ -194,15 +229,41 @@ impl GetHoverContent for tombi_schema_store::AllOfSchema {
                 tombi_schema_store::ValueType::AllOf(value_type_set.into_iter().collect())
             };
 
-            Some(HoverValueContent {
+            let mut hover_value_content = HoverValueContent {
                 title,
                 description,
-                accessors: tombi_schema_store::Accessors::new(accessors.to_vec()),
+                accessors: tombi_schema_store::Accessors::from(accessors.to_vec()),
                 value_type,
                 constraints: None,
                 schema_uri: Some(current_schema.schema_uri.as_ref().to_owned()),
                 range: None,
-            })
+            };
+
+            if let Some(default) = default {
+                if let Some(constraints) = hover_value_content.constraints.as_mut() {
+                    if constraints.default.is_none() {
+                        constraints.default = Some(default);
+                    }
+                } else {
+                    hover_value_content.constraints = Some(ValueConstraints {
+                        default: Some(default),
+                        ..Default::default()
+                    });
+                }
+            }
+
+            if !enumerate_values.is_empty() {
+                if let Some(constraints) = hover_value_content.constraints.as_mut() {
+                    constraints.enumerate = Some(enumerate_values);
+                } else {
+                    hover_value_content.constraints = Some(ValueConstraints {
+                        enumerate: Some(enumerate_values),
+                        ..Default::default()
+                    });
+                }
+            }
+
+            Some(HoverContent::Value(hover_value_content))
         }
         .boxed()
     }
