@@ -317,6 +317,71 @@ mod document_link_tests {
                 }
             ]));
         );
+
+        // Tests for platform specific dependencies (Issue #1192)
+        test_document_link!(
+            #[tokio::test]
+            async fn cargo_target_dependencies_serde(
+                r#"
+                [target.'cfg(unix)'.dependencies]
+                serde = "1.0"
+                "#,
+                project_root_path().join("crates/subcrate/Cargo.toml"),
+            ) -> Ok(Some(vec![
+                {
+                    url: "https://crates.io/crates/serde",
+                    range: 1:0..1:5,
+                    tooltip: tombi_extension_cargo::DocumentLinkToolTip::CrateIo,
+                }
+            ]));
+        );
+
+        test_document_link!(
+            #[tokio::test]
+            async fn cargo_target_dependencies_with_workspace(
+                r#"
+                [target.'cfg(unix)'.dependencies]
+                serde = { workspace = true }
+                "#,
+                project_root_path().join("crates/subcrate/Cargo.toml"),
+            ) -> Ok(Some(vec![
+                {
+                    url: "https://crates.io/crates/serde",
+                    range: 1:0..1:5,
+                    tooltip: tombi_extension_cargo::DocumentLinkToolTip::CrateIo,
+                },
+                {
+                    path: project_root_path().join("Cargo.toml"),
+                    range: 1:10..1:26,
+                    tooltip: tombi_extension_cargo::DocumentLinkToolTip::WorkspaceCargoToml,
+                }
+            ]));
+        );
+
+        test_document_link!(
+            #[tokio::test]
+            async fn cargo_target_dependencies_with_path(
+                r#"
+                [package]
+                name = "test"
+
+                [target.'cfg(unix)'.dependencies]
+                tombi-ast = { path = "../tombi-ast" }
+                "#,
+                project_root_path().join("crates/tombi-lsp/Cargo.toml"),
+            ) -> Ok(Some(vec![
+                {
+                    path: project_root_path().join("crates/tombi-ast/Cargo.toml"),
+                    range: 4:0..4:9,
+                    tooltip: tombi_extension_cargo::DocumentLinkToolTip::CargoToml,
+                },
+                {
+                    path: project_root_path().join("crates/tombi-ast/Cargo.toml"),
+                    range: 4:22..4:34,
+                    tooltip: tombi_extension_cargo::DocumentLinkToolTip::CargoToml,
+                }
+            ]));
+        );
     }
 
     mod tombi_schema {
@@ -327,13 +392,13 @@ mod document_link_tests {
             async fn tombi_schema_catalog_paths(
                 r#"
                 [schema]
-                catalog = { path = "https://json.schemastore.org/api/json/catalog.json" }
+                catalog = { path = "https://www.schemastore.org/api/json/catalog.json" }
                 "#,
                 project_root_path().join("tombi.toml"),
             ) -> Ok(Some(vec![
                 {
-                    url: "https://json.schemastore.org/api/json/catalog.json",
-                    range: 1:20..1:70,
+                    url: "https://www.schemastore.org/api/json/catalog.json",
+                    range: 1:20..1:69,
                     tooltip: tombi_extension_tombi::DocumentLinkToolTip::Catalog,
                 }
             ]));
@@ -344,13 +409,13 @@ mod document_link_tests {
             async fn tombi_schema_catalog_path(
                 r#"
                 [schema]
-                catalog = { paths = ["https://json.schemastore.org/api/json/catalog.json"] }
+                catalog = { paths = ["https://www.schemastore.org/api/json/catalog.json"] }
                 "#,
                 project_root_path().join("tombi.toml"),
             ) -> Ok(Some(vec![
                 {
-                    url: "https://json.schemastore.org/api/json/catalog.json",
-                    range: 1:22..1:72,
+                    url: "https://www.schemastore.org/api/json/catalog.json",
+                    range: 1:22..1:71,
                     tooltip: tombi_extension_tombi::DocumentLinkToolTip::Catalog,
                 }
             ]));
@@ -378,13 +443,13 @@ mod document_link_tests {
             async fn tombi_schemas_remote_path(
                 r#"
                 [[schemas]]
-                path = "https://json.schemastore.org/cargo-make.json"
+                path = "https://www.schemastore.org/cargo-make.json"
                 "#,
                 project_root_path().join("tombi.toml"),
             ) -> Ok(Some(vec![
                 {
-                    url: "https://json.schemastore.org/cargo-make.json",
-                    range: 1:8..1:52,
+                    url: "https://www.schemastore.org/cargo-make.json",
+                    range: 1:8..1:51,
                     tooltip: tombi_extension_tombi::DocumentLinkToolTip::Schema,
                 }
             ]));
