@@ -20,7 +20,7 @@ mod goto_type_definition_tests {
             async fn tombi_schema_catalog_path(
                 r#"
                 [schema.catalog]
-                path = "█https://json.schemastore.org/api/json/catalog.json"
+                path = "█https://www.schemastore.org/api/json/catalog.json"
                 "#,
                 tombi_schema_path(),
             ) -> Ok(tombi_schema_path());
@@ -123,7 +123,7 @@ mod goto_type_definition_tests {
                 format█ = "ruff"
                 "#,
                 pyproject_schema_path(),
-            ) -> Ok("https://json.schemastore.org/partial-taskipy.json");
+            ) -> Ok("https://www.schemastore.org/partial-taskipy.json");
         );
 
         test_goto_type_definition!(
