@@ -4,7 +4,7 @@ use futures::future::join_all;
 use indexmap::IndexSet;
 use tombi_future::{BoxFuture, Boxable};
 use tombi_json::StringNode;
-use tombi_x_keyword::StringFormat;
+use tombi_x_keyword::{StringFormat, TableKeysOrder, X_TOMBI_TABLE_KEYS_ORDER};
 
 use super::{
     referable_schema::CurrentSchema, AllOfSchema, AnyOfSchema, ArraySchema, BooleanSchema,
@@ -207,6 +207,9 @@ impl ValueSchema {
                         .and_then(|v| v.as_array())
                         .map(|array| array.items.iter().map(|v| v.into()).collect()),
                     deprecated: object.get("deprecated").and_then(|v| v.as_bool()),
+                    keys_order: object
+                        .get(X_TOMBI_TABLE_KEYS_ORDER)
+                        .and_then(|v| v.as_str().and_then(|s| TableKeysOrder::try_from(s).ok())),
                 }))
             }
         }
