@@ -2,10 +2,11 @@ use tombi_comment_directive::value::{IntegerCommonFormatRules, IntegerCommonLint
 use tombi_document_tree::ValueImpl;
 use tombi_future::{BoxFuture, Boxable};
 use tombi_schema_store::ValueSchema;
-use tombi_severity_level::{SeverityLevelDefaultError, SeverityLevelDefaultWarn};
+use tombi_severity_level::SeverityLevelDefaultError;
 
 use crate::{
-    comment_directive::get_tombi_key_table_value_rules_and_diagnostics, validate::type_mismatch,
+    comment_directive::get_tombi_key_table_value_rules_and_diagnostics,
+    validate::{push_deprecated_value, type_mismatch},
 };
 
 use super::{validate_all_of, validate_any_of, validate_one_of, Validate};
@@ -284,24 +285,12 @@ async fn validate_integer_schema(
     }
 
     if diagnostics.is_empty() && integer_schema.deprecated == Some(true) {
-        let level = lint_rules
-            .map(|rules| &rules.common)
-            .and_then(|rules| {
-                rules
-                    .deprecated
-                    .as_ref()
-                    .map(SeverityLevelDefaultWarn::from)
-            })
-            .unwrap_or_default();
-
-        crate::Diagnostic {
-            kind: Box::new(crate::DiagnosticKind::DeprecatedValue(
-                tombi_schema_store::SchemaAccessors::from(accessors),
-                value.to_string(),
-            )),
-            range,
-        }
-        .push_diagnostic_with_level(level, &mut diagnostics);
+        push_deprecated_value(
+            &mut diagnostics,
+            accessors,
+            integer_value,
+            lint_rules.as_ref().map(|rules| &rules.common),
+        );
     }
 
     if diagnostics.is_empty() {
@@ -483,24 +472,12 @@ async fn validate_float_schema_for_integer(
     }
 
     if diagnostics.is_empty() && float_schema.deprecated == Some(true) {
-        let level = lint_rules
-            .map(|rules| &rules.common)
-            .and_then(|rules| {
-                rules
-                    .deprecated
-                    .as_ref()
-                    .map(SeverityLevelDefaultWarn::from)
-            })
-            .unwrap_or_default();
-
-        crate::Diagnostic {
-            kind: Box::new(crate::DiagnosticKind::DeprecatedValue(
-                tombi_schema_store::SchemaAccessors::from(accessors),
-                value.to_string(),
-            )),
-            range,
-        }
-        .push_diagnostic_with_level(level, &mut diagnostics);
+        push_deprecated_value(
+            &mut diagnostics,
+            accessors,
+            integer_value,
+            lint_rules.as_ref().map(|rules| &rules.common),
+        );
     }
 
     if diagnostics.is_empty() {
