@@ -4,7 +4,6 @@ use similar::{ChangeTag, TextDiff};
 use tokio::io::{AsyncReadExt, AsyncSeekExt, AsyncWriteExt};
 use tombi_config::{FormatOptions, TomlVersion};
 use tombi_diagnostic::{printer::Pretty, Diagnostic, Print};
-use tombi_formatter::formatter::definitions::FormatDefinitions;
 use tombi_glob::{FileInputType, FileSearch};
 
 use crate::app::CommonArgs;
@@ -88,6 +87,8 @@ where
     crate::Error: Print<P>,
     P: Clone + Send + 'static,
 {
+    let use_ansi_color = std::env::var("NO_COLOR").map_or(true, |v| v.is_empty());
+
     let (config, config_path, config_level) = serde_tombi::config::load_with_path_and_level(
         std::env::current_dir().ok(),
     )
@@ -145,6 +146,7 @@ where
                     args.diff,
                     &format_options,
                     &schema_store,
+                    use_ansi_color,
                 )
                 .await
                 {
@@ -176,6 +178,7 @@ where
                                             args.diff,
                                             &format_options,
                                             &schema_store,
+                                            use_ansi_color,
                                         )
                                         .await
                                     });
@@ -185,16 +188,16 @@ where
                                         crate::Error::TombiGlob(tombi_glob::Error::FileNotFound(
                                             source_path,
                                         ))
-                                        .print(&mut printer);
+                                        .print(&mut printer, use_ansi_color);
                                     } else {
-                                        crate::Error::Io(err).print(&mut printer);
+                                        crate::Error::Io(err).print(&mut printer, use_ansi_color);
                                     }
                                     error_num += 1;
                                 }
                             }
                         }
                         Err(err) => {
-                            crate::Error::TombiGlob(err).print(&mut printer);
+                            crate::Error::TombiGlob(err).print(&mut printer, use_ansi_color);
                             error_num += 1;
                         }
                     }
@@ -222,7 +225,7 @@ where
 
                 if !errors.is_empty() {
                     for error in errors {
-                        error.print(&mut printer);
+                        error.print(&mut printer, use_ansi_color);
                     }
                 }
             }
@@ -243,19 +246,18 @@ async fn format_stdin<P>(
     diff: bool,
     format_options: &FormatOptions,
     schema_store: &tombi_schema_store::SchemaStore,
+    use_ansi_color: bool,
 ) -> Result<bool, crate::Error>
 where
     Diagnostic: Print<P>,
     crate::Error: Print<P>,
 {
     let mut source = String::new();
-    let format_definitions = FormatDefinitions::default();
     if let Err(err) = file.read_to_string(&mut source).await {
         return Err(crate::Error::Io(err));
     }
     match tombi_formatter::Formatter::new(
         toml_version,
-        &format_definitions,
         format_options,
         file.source().map(itertools::Either::Right),
         schema_store,
@@ -282,7 +284,7 @@ where
         }
         Err(diagnostics) => {
             print!("{source}");
-            diagnostics.print(&mut printer);
+            diagnostics.print(&mut printer, use_ansi_color);
             Err(crate::Error::StdinParseFailed)
         }
     }
@@ -297,19 +299,18 @@ async fn format_file<P>(
     diff: bool,
     format_options: &FormatOptions,
     schema_store: &tombi_schema_store::SchemaStore,
+    use_ansi_color: bool,
 ) -> Result<bool, crate::Error>
 where
     Diagnostic: Print<P>,
     crate::Error: Print<P>,
 {
     let mut source = String::new();
-    let format_definitions = FormatDefinitions::default();
     if let Err(err) = file.read_to_string(&mut source).await {
         return Err(crate::Error::Io(err));
     }
     match tombi_formatter::Formatter::new(
         toml_version,
-        &format_definitions,
         format_options,
         Some(itertools::Either::Right(source_path)),
         schema_store,
@@ -342,7 +343,7 @@ where
                 .into_iter()
                 .map(|diagnostic| diagnostic.with_source_file(source_path))
                 .collect_vec()
-                .print(&mut printer);
+                .print(&mut printer, use_ansi_color);
             Err(crate::Error::FileParseFailed(source_path.to_owned()))
         }
     }
